@@ -1,4 +1,4 @@
-`matMeans` <-
+matMeans <-
 function (lis) {
     matSums(lis) / length(lis)
 }
