@@ -8,7 +8,7 @@ function (object, resp.patterns = NULL, order = TRUE, ...) {
     X <- fits[, -ncol(fits), drop = FALSE]
     Exp <- fits[, "Exp"]
     Obs <- observedFreqs(object, X)
-    out <- cbind(X, Obs = Obs, Exp = Exp, Resid = round((Obs - Exp) / sqrt(Exp), 3))
+    out <- cbind(X, Obs = Obs, Exp = Exp, Resid = (Obs - Exp) / sqrt(Exp))
     if (order)
         out <- out[order(out[, "Resid"]), ]
     out
